"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.ModuleBase = void 0;
const angular_1 = require("angular");
const paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
const angular_service_1 = require("./services/angular.service");
const registrable_1 = require("./decorators/registrable");
class ModuleBase {
    constructor() {
        this.controllersQueue = new Array();
        this.interceptorsQueue = new Array();
        this.module = (0, angular_1.module)(this.getModuleName(), this.getModuleDependencies());
        this.register();
        this.module.config([angular_service_1.AngularServices.stateProvider, angular_service_1.AngularServices.urlRouterProvider, angular_service_1.AngularServices.httpProvider, angular_service_1.AngularServices.locationProvider, (stateProvider, urlRouterProvider, httpProvider, location) => this.configureRoutes(stateProvider, urlRouterProvider, httpProvider, location)]);
        this.module.config([angular_service_1.AngularServices.translateProvider, translateProvider => this.configureTranslator(translateProvider)]);
        this.module.config([angular_service_1.AngularServices.compileProvider, compileProvider => compileProvider.debugInfoEnabled(false)]);
        this.module.config([angular_service_1.AngularServices.httpProvider, provider => this.registerInterceptorsInternally(provider)]);
        this.module.config([angular_service_1.AngularServices.stateProvider, provider => this.registerStates(provider)]);
        this.module.run([angular_service_1.AngularServices.rootScope, angular_service_1.AngularServices.state, angular_service_1.AngularServices.injector, (rootScope, state, injector) => this.authorizeRoute(rootScope, state, injector)]);
    }
    getModule() {
        return this.module;
    }
    getModuleName() {
        throw new Error("Please override getModuleName method and provide a name for the module.");
    }
    registerControllers(controllers) {
        paradigm_ui_web_shared_1.ArrayExtensions.forEach(controllers, x => this.registerController(x));
    }
    registerController(controller) {
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(controller) ||
            paradigm_ui_web_shared_1.ObjectExtensions.isNull(controller[registrable_1.registrableMetadataKey]))
            throw new Error(`Problems registering the controller '${paradigm_ui_web_shared_1.FunctionExtensions.getFunctionName(controller)}'.`);
        const controllerInfo = controller[registrable_1.registrableMetadataKey];
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(controllerInfo.dependencies))
            controller.$inject = this.getDedependencies(controllerInfo.dependencies);
        this.module.controller(controllerInfo.name, controller);
        this.logger.debug(`registering ${controllerInfo.name}`);
        if (this.stateProvider == null)
            this.controllersQueue.push(controller);
        else
            this.registerControllerState(controller);
    }
    registerComponents(Components) {
        paradigm_ui_web_shared_1.ArrayExtensions.forEach(Components, x => this.registerComponent(x));
    }
    registerComponent(component) {
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(component) ||
            paradigm_ui_web_shared_1.ObjectExtensions.isNull(component[registrable_1.registrableMetadataKey]))
            throw new Error(`Problems registering the component '${paradigm_ui_web_shared_1.FunctionExtensions.getFunctionName(component)}'.`);
        const componentInfo = component[registrable_1.registrableMetadataKey];
        const parameters = (this.getDedependencies(componentInfo.dependencies) || new Array());
        parameters.push(componentInfo.controller);
        this.module.component(componentInfo.name, {
            controller: parameters,
            controllerAs: componentInfo.controllerAs || "component",
            templateUrl: componentInfo.templateUrl,
            template: componentInfo.template,
            bindings: componentInfo.bindings,
            transclude: componentInfo.transclude,
            require: componentInfo.require
        });
        this.logger.debug(`registering ${componentInfo.name}`);
    }
    registerServices(services) {
        paradigm_ui_web_shared_1.ArrayExtensions.forEach(services, x => this.registerService(x));
    }
    registerService(service) {
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(service) ||
            paradigm_ui_web_shared_1.ObjectExtensions.isNull(service[registrable_1.registrableMetadataKey]))
            throw new Error(`Problems registering the service '${paradigm_ui_web_shared_1.FunctionExtensions.getFunctionName(service)}'.`);
        const serviceInfo = service[registrable_1.registrableMetadataKey];
        const parameters = (this.getDedependencies(serviceInfo.dependencies) || new Array());
        parameters.push(serviceInfo.factory);
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(serviceInfo.factory))
            throw new Error("Missing service factory.");
        this.module.factory(serviceInfo.name, parameters);
        this.logger.debug(`registering ${serviceInfo.name}`);
    }
    registerLoggingService(service) {
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(service) ||
            paradigm_ui_web_shared_1.ObjectExtensions.isNull(service[registrable_1.registrableMetadataKey]))
            throw new Error(`Problems registering the logging service '${paradigm_ui_web_shared_1.FunctionExtensions.getFunctionName(service)}'.`);
        const serviceInfo = service[registrable_1.registrableMetadataKey];
        const parameters = (this.getDedependencies(serviceInfo.dependencies) || new Array());
        parameters.push(serviceInfo.factory);
        this.module.factory(serviceInfo.name, parameters);
        this.logger = serviceInfo.factory();
        this.logger.debug(`registering ${serviceInfo.name}`);
    }
    registerInterceptors(interceptors) {
        paradigm_ui_web_shared_1.ArrayExtensions.forEach(interceptors, x => this.registerInterceptor(x));
    }
    registerInterceptor(interceptor) {
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(interceptor) ||
            paradigm_ui_web_shared_1.ObjectExtensions.isNull(interceptor[registrable_1.registrableMetadataKey]))
            throw new Error(`Problems registering the interceptor '${paradigm_ui_web_shared_1.FunctionExtensions.getFunctionName(interceptor)}'.`);
        const interceptorInfo = interceptor[registrable_1.registrableMetadataKey];
        if (this.httpProvider == null)
            this.interceptorsQueue.push(interceptor);
        else {
            const parameters = (this.getDedependencies(interceptorInfo.dependencies) || new Array());
            parameters.push(interceptorInfo.factory);
            this.httpProvider.interceptors.push(parameters);
        }
        this.logger.debug(`registering ${interceptorInfo.name}`);
    }
    registerFilters(filters) {
        paradigm_ui_web_shared_1.ArrayExtensions.forEach(filters, x => this.registerFilter(x));
    }
    registerFilter(filter) {
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(filter) ||
            paradigm_ui_web_shared_1.ObjectExtensions.isNull(filter[registrable_1.registrableMetadataKey]))
            throw new Error(`Problems registering the filter '${paradigm_ui_web_shared_1.FunctionExtensions.getFunctionName(filter)}'.`);
        const filterInfo = filter[registrable_1.registrableMetadataKey];
        const parameters = (this.getDedependencies(filterInfo.dependencies) || new Array());
        parameters.push(filterInfo.factory);
        this.module.filter(filterInfo.name, parameters);
        this.logger.debug(`registering ${filterInfo.name}`);
    }
    registerDirectives(directives) {
        paradigm_ui_web_shared_1.ArrayExtensions.forEach(directives, x => this.registerDirective(x));
    }
    registerDirective(directive) {
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(directive) ||
            paradigm_ui_web_shared_1.ObjectExtensions.isNull(directive[registrable_1.registrableMetadataKey]))
            throw new Error(`Problems registering the directive '${paradigm_ui_web_shared_1.FunctionExtensions.getFunctionName(directive)}'.`);
        const directiveInfo = directive[registrable_1.registrableMetadataKey];
        const parameters = (this.getDedependencies(directiveInfo.dependencies) || new Array());
        parameters.push(directiveInfo.factory);
        this.module.directive(directiveInfo.name, parameters);
        this.logger.debug(`registering ${directiveInfo.name}`);
    }
    registerStates(stateProvider) {
        this.stateProvider = stateProvider;
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(this.controllersQueue)) {
            for (let i = 0; i < this.controllersQueue.length; i++) {
                this.registerControllerState(this.controllersQueue[i]);
            }
            this.controllersQueue = null;
        }
    }
    registerInterceptorsInternally(httpProvider) {
        this.httpProvider = httpProvider;
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(this.interceptorsQueue)) {
            for (let i = 0; i < this.interceptorsQueue.length; i++) {
                this.registerInterceptor(this.interceptorsQueue[i]);
            }
            this.interceptorsQueue = null;
        }
    }
    registerControllerState(controller) {
        var controllerInfo = controller[registrable_1.registrableMetadataKey];
        if (controllerInfo.stateName == null)
            return;
        this.stateProvider.state(controllerInfo.stateName, {
            controllerAs: controllerInfo.controllerAs,
            url: controllerInfo.stateUrl,
            templateUrl: controllerInfo.templateUrl,
            template: controllerInfo.template,
            resolve: controllerInfo.resolve,
            params: controllerInfo.params
        });
    }
    getDedependencies(dependencies) {
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(dependencies))
            return null;
        return paradigm_ui_web_shared_1.ArrayExtensions.select(dependencies, x => (paradigm_ui_web_shared_1.ObjectExtensions.getTypeName(x) === "String")
            ? x
            : (0, registrable_1.getRegistrableName)(x) || paradigm_ui_web_shared_1.FunctionExtensions.getFunctionName(x));
    }
    configureRoutes(stateProvider, urlRouterProvider, httpProvider, locationProvider) {
        /* override if needed */
    }
    authorizeRoute(rootScope, state, injector) {
        /* override if needed */
    }
    configureTranslator(translateProvider) {
        /* override if needed */
    }
    getModuleDependencies() {
        throw new Error("Please override getModuleDependencies method and provide other required modules or an empty array.");
    }
    register() {
        // override this method to change the base logging service.
    }
}
exports.ModuleBase = ModuleBase;
//# sourceMappingURL=base.module.js.map