"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
Object.defineProperty(exports, "__esModule", { value: true });
const angular_1 = require("angular");
const framework_module_1 = require("../framework.module");
const angular_service_1 = require("../services/angular.service");
const mock_component_spec_1 = require("../mocks/mock.component.spec");
const logging_service_1 = require("../services/logging.service");
const injector_service_1 = require("../services/injector.service");
const registrable_1 = require("../decorators/registrable");
describe("MockComponent", () => {
    var rootScopeService;
    var injector;
    var logger = new logging_service_1.LoggingService();
    beforeEach(() => {
        // create a new framework module with all the configuration.
        angular_1.mock.module(framework_module_1.FrameworkModule.instance.getModuleName());
        // inject a dummy logging service to prevent undesired logging.
        angular_1.mock.module($provide => {
            $provide.value((0, registrable_1.getRegistrableName)(logging_service_1.LoggingService), logger);
        });
    });
    // prepare base services and classes.
    beforeEach(inject(($injector) => {
        injector = injector_service_1.InjectorService.factory($injector);
        rootScopeService = injector.get(angular_service_1.AngularServices.rootScope);
    }));
    function getComponent() {
        return new mock_component_spec_1.MockComponent(rootScopeService.$new(false, rootScopeService), injector);
    }
    describe("structure", () => {
        it("shuld have bindings", () => {
            expect(mock_component_spec_1.MockComponent).not.toBeNull();
            var parameters = mock_component_spec_1.MockComponent[registrable_1.registrableMetadataKey];
            expect(parameters).not.toBeNull();
            expect(parameters.bindings).not.toBeNull();
            expect(parameters.bindings["name"]).toBe("@");
            expect(parameters.bindings["person"]).toBe("<");
            expect(parameters.bindings["onCreated"]).toBe("&");
            expect(parameters.bindings["parent"]).toBe("=");
        });
        it("shuld have requirements", () => {
            expect(mock_component_spec_1.MockComponent).not.toBeNull();
            var parameters = mock_component_spec_1.MockComponent[registrable_1.registrableMetadataKey];
            expect(parameters).not.toBeNull();
            expect(parameters.require).not.toBeNull();
            expect(parameters.require["firstRequire"]).toBe("^MockComponent");
            expect(parameters.require["secondRequire"]).toBe("ngModel");
        });
    });
    describe("construction", () => {
        it("shuld instantiate test Component", () => {
            var component = getComponent();
            expect(component).not.toBeNull();
        });
    });
});
//# sourceMappingURL=base.component.spec.js.map