"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
var KeyboardListenerDirective_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeyboardListenerDirective = void 0;
const tslib_1 = require("tslib");
const directive_1 = require("../decorators/directive");
const base_directive_1 = require("./base.directive");
const key_processor_service_1 = require("../services/key-processor.service");
const $ = require("jquery");
let KeyboardListenerDirective = KeyboardListenerDirective_1 = class KeyboardListenerDirective extends base_directive_1.DirectiveBase {
    constructor(keyProcessor) {
        super();
        this.keyProcessor = keyProcessor;
    }
    onInit(scope, instanceElement, instanceAttributes, controller, transclude) {
        var actions = ``;
        var attachTo = $(scope.attachTo || document);
        var id = instanceElement[0].id;
        instanceElement.find(`listener`).each((index, element) => {
            actions += element.getAttribute(`action`) + `|`;
        });
        if (actions[actions.length - 1] === `|`)
            actions = actions.substr(0, actions.length - 1);
        var keyActions = this.keyProcessor.parseActions(actions);
        var keyProcessor = this.keyProcessor;
        function evaluateKeyPress(e) {
            if (scope.disabled)
                return;
            keyProcessor.evaluateKeyActions(keyActions, `keypress`, scope.$parent, e);
        }
        function evaluateKeyDown(e) {
            if (scope.disabled)
                return;
            keyProcessor.evaluateKeyActions(keyActions, `keydown`, scope.$parent, e);
        }
        function evaluateKeyUp(e) {
            if (scope.disabled)
                return;
            keyProcessor.evaluateKeyActions(keyActions, `keyup`, scope.$parent, e);
        }
        if (keyActions.any(x => x.eventType === `keypress`))
            attachTo.on(`keypress.${id}.documentKeyboard`, evaluateKeyPress);
        if (keyActions.any(x => x.eventType === `keydown`))
            attachTo.on(`keydown.${id}.documentKeyboard`, evaluateKeyDown);
        if (keyActions.any(x => x.eventType === `keyup`))
            attachTo.on(`keyup.${id}.documentKeyboard`, evaluateKeyUp);
    }
    onDestroy(scope, instanceElement, instanceAttributes, controller, transclude) {
        var attachTo = $(scope.attachTo || document);
        var id = instanceElement[0].id;
        attachTo.off(`keypress.${id}.documentKeyboard`);
        attachTo.off(`keydown.${id}.documentKeyboard`);
        attachTo.off(`keyup.${id}.documentKeyboard`);
        super.onDestroy(scope, instanceElement, instanceAttributes, controller, transclude);
    }
    static factory(keyProcessor) {
        return new KeyboardListenerDirective_1(keyProcessor);
    }
};
KeyboardListenerDirective = KeyboardListenerDirective_1 = (0, tslib_1.__decorate)([
    (0, directive_1.Directive)({
        name: "keyboardListener",
        restrict: "E",
        bindings: {
            disabled: "=",
            attachTo: "@"
        },
        dependencies: [key_processor_service_1.KeyProcessorService]
    })
], KeyboardListenerDirective);
exports.KeyboardListenerDirective = KeyboardListenerDirective;
//# sourceMappingURL=keyboard-listener.directive.js.map