"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpServiceBase = void 0;
const base_service_1 = require("./base.service");
const paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
class HttpServiceBase extends base_service_1.ServiceBase {
    constructor(http, host) {
        super();
        this.http = http;
        this.host = host;
    }
    get(url, parameters) {
        return this.http.get(this.getUrl(url, parameters), { responseType: "json", headers: this.getHeaders() });
    }
    post(url, parameters, body) {
        return this.http.post(this.getUrl(url, parameters), body, { responseType: "json", headers: this.getHeaders() });
    }
    put(url, parameters, body) {
        return this.http.put(this.getUrl(url, parameters), body, { responseType: "json", headers: this.getHeaders() });
    }
    patch(url, parameters, body) {
        return this.http.patch(this.getUrl(url, parameters), body, { responseType: "json", headers: this.getHeaders() });
    }
    delete(url, parameters) {
        return this.http.delete(this.getUrl(url, parameters), { responseType: "json", headers: this.getHeaders() });
    }
    options(url, parameters) {
        throw Error("Http verb not supported.");
    }
    getStringValue(value) {
        if (paradigm_ui_web_shared_1.ObjectExtensions.isNull(value))
            return "";
        if (paradigm_ui_web_shared_1.ObjectExtensions.getTypeName(value) === "Number" ||
            paradigm_ui_web_shared_1.ObjectExtensions.getTypeName(value) === "String" ||
            paradigm_ui_web_shared_1.ObjectExtensions.getTypeName(value) === "Boolean") {
            return value.toString();
        }
        if (paradigm_ui_web_shared_1.ObjectExtensions.getTypeName(value) === "Date") {
            return paradigm_ui_web_shared_1.DateExtensions.formatUTC(value, "yyyy-MM-ddThh:mm:ss.fff");
        }
        return "";
    }
    getUrl(url, params) {
        if (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(params)) {
            for (let key in params) {
                if (params.hasOwnProperty(key)) {
                    url = url.replace(`{${key}}`, this.getStringValue(params[key]));
                }
            }
        }
        return `${this.host}${url}`;
    }
    getHeaders() {
        return { "Content-Type": "application/json; charset=utf-8" };
    }
}
exports.HttpServiceBase = HttpServiceBase;
//# sourceMappingURL=http-base.service.js.map