"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
var KeyProcessorService_1;
Object.defineProperty(exports, "__esModule", { value: true });
exports.KeyAction = exports.KeyProcessorService = void 0;
const tslib_1 = require("tslib");
const base_service_1 = require("./base.service");
const service_1 = require("../decorators/service");
const angular_service_1 = require("./angular.service");
const paradigm_ui_web_shared_1 = require("@miracledevs/paradigm-ui-web-shared");
let KeyProcessorService = KeyProcessorService_1 = class KeyProcessorService extends base_service_1.ServiceBase {
    constructor(parse) {
        super();
        this.parse = parse;
    }
    evaluateKeyActions(keyActions, eventType, scope, e) {
        keyActions.where(x => x.eventType === eventType).forEach(keyAction => {
            if (e.keyCode === keyAction.keyCode &&
                ((paradigm_ui_web_shared_1.ObjectExtensions.isNull(keyAction.shift)) ||
                    (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(keyAction.shift) && keyAction.shift && e.shiftKey) ||
                    (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(keyAction.shift) && !keyAction.shift && !e.shiftKey)) &&
                ((paradigm_ui_web_shared_1.ObjectExtensions.isNull(keyAction.alt)) ||
                    (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(keyAction.alt) && keyAction.alt && e.altKey) ||
                    (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(keyAction.alt) && !keyAction.alt && !e.altKey)) &&
                ((paradigm_ui_web_shared_1.ObjectExtensions.isNull(keyAction.ctrl)) ||
                    (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(keyAction.ctrl) && keyAction.ctrl && e.ctrlKey) ||
                    (!paradigm_ui_web_shared_1.ObjectExtensions.isNull(keyAction.ctrl) && !keyAction.ctrl && !e.ctrlKey))) {
                scope.$apply(() => {
                    keyAction.action(scope, { $event: e });
                });
            }
        });
    }
    parseActions(text) {
        const keyActions = new paradigm_ui_web_shared_1.ArrayList();
        const actionStrings = text.split("|");
        for (let i = 0; i < actionStrings.length; i++) {
            const keyAction = new KeyAction();
            const actionString = actionStrings[i];
            const parts = actionString.split(":");
            if (parts.length !== 2)
                throw new Error(`The key-submit expression number ${i} is incorrect. Should be event(keycode,[shift],[alt],[ctrl]): action`);
            const firstParenthesis = parts[0].indexOf("(");
            const lastParenthesis = parts[0].indexOf(")");
            if (firstParenthesis < 0 || lastParenthesis < 0)
                throw new Error(`The key-submit expression number ${i} is incorrect. Should be event(keycode,[shift],[alt],[ctrl]): action`);
            const eventType = parts[0].substr(0, firstParenthesis);
            if (eventType !== "keypress" &&
                eventType !== "keydown" &&
                eventType !== "keyup")
                throw new Error(`Only keypress, keydown and keyup events are allowed on action strings.`);
            const keys = parts[0].substr(firstParenthesis + 1, lastParenthesis - firstParenthesis - 1);
            const parameters = new paradigm_ui_web_shared_1.ArrayList(keys.split(","));
            try {
                keyAction.eventType = eventType;
                keyAction.action = this.parse(parts[1]);
                keyAction.keyCode = parseInt(parameters.get(0), 10);
            }
            catch (error) {
                throw new Error(`The key-submit expression number ${i} is incorrect. Should be event(keycode,[shift],[alt],[ctrl]): action.`);
            }
            if (parameters.any(x => x === "shift"))
                keyAction.shift = true;
            else if (parameters.any(x => x === "!shift"))
                keyAction.shift = false;
            if (parameters.any(x => x === "ctrl"))
                keyAction.ctrl = true;
            else if (parameters.any(x => x === "!ctrl"))
                keyAction.ctrl = false;
            if (parameters.any(x => x === "alt"))
                keyAction.alt = true;
            else if (parameters.any(x => x === "!alt"))
                keyAction.alt = false;
            keyActions.add(keyAction);
        }
        return keyActions;
    }
    static factory(parse) {
        return new KeyProcessorService_1(parse);
    }
};
KeyProcessorService = KeyProcessorService_1 = (0, tslib_1.__decorate)([
    (0, service_1.Service)({ name: "$pd-keyProcessorService", dependencies: [angular_service_1.AngularServices.parse] })
], KeyProcessorService);
exports.KeyProcessorService = KeyProcessorService;
class KeyAction {
}
exports.KeyAction = KeyAction;
//# sourceMappingURL=key-processor.service.js.map