/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
import { ServiceBase } from "./base.service";
export declare enum LogType {
    Trace = 0,
    Debug = 1,
    Information = 2,
    Warning = 3,
    Error = 4,
    Critical = 5
}
export declare class LoggingService extends ServiceBase {
    private static readonly typeNotRecognized;
    private messages;
    private minimumLevel;
    constructor();
    /**
     * Sets the custom message for a given log type.
     * There are some predefined content placeholders the user can utilize
     * to configure the custom messages:
     * {0}: The time when the log was added.
     * {1}: The type of the log (Trace, Debug , Information, etc)
     * {2}: A custom tag value provided by the user.
     * {3}: The log message.
     */
    setCustomMessage(type: LogType, message: string): void;
    /**
     * Sets the minimum log level.
     */
    setMinimumLevel(type: LogType): void;
    /**
     * Logs the specified message.
     */
    log(message: string, type?: LogType, tag?: string): void;
    trace(message: string, tag?: string): void;
    debug(message: string, tag?: string): void;
    information(message: string, tag?: string): void;
    warning(message: string, tag?: string): void;
    error(message: string, tag?: string): void;
    critical(message: string, tag?: string): void;
    static factory(): LoggingService;
}
