"use strict";
/*!
 * Paradigm Framework - AngularJS Wrapper
 * Copyright (c) 2017 Miracle Devs, Inc
 * Licensed under MIT (https://github.com/MiracleDevs/Paradigm.Web.Shared/blob/master/LICENSE)
 */
Object.defineProperty(exports, "__esModule", { value: true });
const angular_1 = require("angular");
const mock_service_spec_1 = require("../mocks/mock.service.spec");
const framework_module_1 = require("../framework.module");
const mock_message_spec_1 = require("../mocks/mock.message.spec");
const message_bus_service_1 = require("./message-bus.service");
const logging_service_1 = require("./logging.service");
const injector_service_1 = require("./injector.service");
const registrable_1 = require("../decorators/registrable");
describe("MessageBus", () => {
    var injector;
    var messageBus;
    var logger = new mock_service_spec_1.TestLoggingService();
    beforeEach(() => {
        // create a new framework module with all the configuration.
        angular_1.mock.module(framework_module_1.FrameworkModule.instance.getModuleName());
        // inject a dummy logging service to prevent undesired logging.
        angular_1.mock.module($provide => {
            $provide.value((0, registrable_1.getRegistrableName)(logging_service_1.LoggingService), logger);
        });
    });
    // prepare base services and classes.
    beforeEach(inject(($injector) => {
        injector = injector_service_1.InjectorService.factory($injector);
        messageBus = injector.get(message_bus_service_1.MessageBus);
    }));
    describe("creating the service", () => {
        it("should initialize correctly", () => {
            expect(messageBus).toBeDefined();
        });
        it("message bus should be empty", () => {
            expect(messageBus.count()).toBe(0);
        });
    });
    describe("working with messages", () => {
        it("should register and unregister a message", () => {
            var token;
            expect(() => token = messageBus.register(mock_message_spec_1.MockMessage, () => 0)).not.toThrow();
            expect(token).not.toBe(null);
            expect(messageBus.count()).toBe(1);
            expect(messageBus.isRegistered(mock_message_spec_1.MockMessage)).toBe(true);
            expect(messageBus.handlerCount(mock_message_spec_1.MockMessage)).toBe(1);
            expect(() => messageBus.unregister(token)).not.toThrow();
            expect(messageBus.count()).toBe(0);
            expect(messageBus.isRegistered(mock_message_spec_1.MockMessage)).toBe(false);
            expect(messageBus.handlerCount(mock_message_spec_1.MockMessage)).toBe(0);
        });
        it("should send a message", () => {
            var response;
            var token = messageBus.register(mock_message_spec_1.MockMessage, x => response = x.someValue);
            expect(() => messageBus.send(new mock_message_spec_1.MockMessage("Test Value"))).not.toThrow();
            expect(response).toBe("Test Value");
            messageBus.unregister(token);
        });
    });
});
//# sourceMappingURL=message-bus.service.spec.js.map